@@ -1489,7 +1489,7 @@ def create_database(path, enable_wal, init_spatialite, load_extension):
 )
 @click.argument("table")
 @click.argument("columns", nargs=-1, required=True)
-@click.option("--pk", help="Column to use as primary key")
+@click.option("pks", "--pk", help="Column to use as primary key", multiple=True)
 @click.option(
     "--not-null",
     multiple=True,
@@ -1532,7 +1532,7 @@ def create_table(
     path,
     table,
     columns,
-    pk,
+    pks,
     not_null,
     default,
     fk,
@@ -1581,7 +1581,7 @@ def create_table(
             )
     db[table].create(
         coltypes,
-        pk=pk,
+        pk=pks[0] if len(pks) == 1 else pks,
         not_null=not_null,
         defaults=dict(default),
         foreign_keys=fk,
@@ -1894,6 +1894,7 @@ def memory(
     save,
     analyze,
     load_extension,
+    return_db=False,
 ):
     """Execute SQL query against an in-memory database, optionally populated by imported data
 
@@ -1922,6 +1923,7 @@ def memory(
         sqlite-utils memory animals.csv --schema
     """
     db = sqlite_utils.Database(memory=True)
+
     # If --dump or --save or --analyze used but no paths detected, assume SQL query is a path:
     if (dump or save or schema or analyze) and not paths:
         paths = [sql]
@@ -1954,6 +1956,7 @@ def memory(
             rows = tracker.wrap(rows)
         if flatten:
             rows = (_flatten(row) for row in rows)
+
         db[file_table].insert_all(rows, alter=True)
         if tracker is not None:
             db[file_table].transform(types=tracker.types)
@@ -1964,6 +1967,7 @@ def memory(
         for view_name in view_names:
             if not db[view_name].exists():
                 db.create_view(view_name, "select * from [{}]".format(file_table))
+
         if fp:
             fp.close()
 
@@ -1994,6 +1998,9 @@ def memory(
     if functions:
         _register_functions(db, functions)
 
+    if return_db:
+        return db
+
     _execute_query(
         db,
         sql,
@@ -2594,7 +2601,7 @@ def extract(
     multiple=True,
     help="Column definitions for the table",
 )
-@click.option("--pk", type=str, help="Column to use as primary key")
+@click.option("pks", "--pk", help="Column to use as primary key", multiple=True)
 @click.option("--alter", is_flag=True, help="Alter table to add missing columns")
 @click.option("--replace", is_flag=True, help="Replace files with matching primary key")
 @click.option("--upsert", is_flag=True, help="Upsert files with matching primary key")
@@ -2611,7 +2618,7 @@ def insert_files(
     table,
     file_or_dir,
     column,
-    pk,
+    pks,
     alter,
     replace,
     upsert,
@@ -2641,8 +2648,8 @@ def insert_files(
             column = ["path:path", "content_text:content_text", "size:size"]
         else:
             column = ["path:path", "content:content", "size:size"]
-        if not pk:
-            pk = "path"
+        if not pks:
+            pks = ["path"]
 
     def yield_paths_and_relative_paths():
         for f_or_d in file_or_dir:
@@ -2712,7 +2719,11 @@ def insert_files(
         try:
             with db.conn:
                 db[table].insert_all(
-                    to_insert(), pk=pk, alter=alter, replace=replace, upsert=upsert
+                    to_insert(),
+                    pk=pks[0] if len(pks) == 1 else pks,
+                    alter=alter,
+                    replace=replace,
+                    upsert=upsert,
                 )
         except UnicodeDecodeErrorForPath as e:
             raise click.ClickException(
@@ -2871,9 +2882,9 @@ def _generate_convert_help():
     Convert columns using Python code you supply. For example:
 
     \b
-        sqlite-utils convert my.db mytable mycolumn \\
-            '"\\n".join(textwrap.wrap(value, 10))' \\
-            --import=textwrap
+    sqlite-utils convert my.db mytable mycolumn \\
+        '"\\n".join(textwrap.wrap(value, 10))' \\
+        --import=textwrap
 
     "value" is a variable with the column value to be converted.
 
@@ -2892,7 +2903,7 @@ def _generate_convert_help():
     for name in recipe_names:
         fn = getattr(recipes, name)
         help += "\n\nr.{}{}\n\n\b{}".format(
-            name, str(inspect.signature(fn)), fn.__doc__.rstrip()
+            name, str(inspect.signature(fn)), textwrap.dedent(fn.__doc__.rstrip())
         )
     help += "\n\n"
     help += textwrap.dedent(
@@ -2900,8 +2911,8 @@ def _generate_convert_help():
     You can use these recipes like so:
 
     \b
-        sqlite-utils convert my.db mytable mycolumn \\
-            'r.jsonsplit(value, delimiter=":")'
+    sqlite-utils convert my.db mytable mycolumn \\
+        'r.jsonsplit(value, delimiter=":")'
     """
     ).strip()
     return help
