@@ -1350,8 +1350,14 @@ def test_insert_upsert_strict(fresh_db, method_name, strict):
 
 @pytest.mark.parametrize("strict", (False, True))
 def test_create_table_strict(fresh_db, strict):
-    table = fresh_db.create_table("t", {"id": int}, strict=strict)
+    table = fresh_db.create_table("t", {"id": int, "f": float}, strict=strict)
     assert table.strict == strict or not fresh_db.supports_strict
+    expected_schema = "CREATE TABLE [t] (\n" "   [id] INTEGER,\n" "   [f] FLOAT\n" ")"
+    if strict and not fresh_db.supports_strict:
+        return
+    if strict:
+        expected_schema = "CREATE TABLE [t] (\n   [id] INTEGER,\n   [f] REAL\n) STRICT"
+    assert table.schema == expected_schema
 
 
 @pytest.mark.parametrize("strict", (False, True))
