@@ -26,11 +26,8 @@ def test_extract_single_column(fresh_db, table, fk_column):
         'CREATE TABLE "tree" (\n'
         "   [id] INTEGER PRIMARY KEY,\n"
         "   [name] TEXT,\n"
-        "   [{}] INTEGER,\n".format(expected_fk)
-        + "   [end] INTEGER,\n"
-        + "   FOREIGN KEY([{}]) REFERENCES [{}]([id])\n".format(
-            expected_fk, expected_table
-        )
+        "   [{}] INTEGER REFERENCES [{}]([id]),\n".format(expected_fk, expected_table)
+        + "   [end] INTEGER\n"
         + ")"
     )
     assert fresh_db[expected_table].schema == (
@@ -76,8 +73,7 @@ def test_extract_multiple_columns_with_rename(fresh_db):
         'CREATE TABLE "tree" (\n'
         "   [id] INTEGER PRIMARY KEY,\n"
         "   [name] TEXT,\n"
-        "   [common_name_latin_name_id] INTEGER,\n"
-        "   FOREIGN KEY([common_name_latin_name_id]) REFERENCES [common_name_latin_name]([id])\n"
+        "   [common_name_latin_name_id] INTEGER REFERENCES [common_name_latin_name]([id])\n"
         ")"
     )
     assert fresh_db["common_name_latin_name"].schema == (
@@ -127,8 +123,7 @@ def test_extract_rowid_table(fresh_db):
     assert fresh_db["tree"].schema == (
         'CREATE TABLE "tree" (\n'
         "   [name] TEXT,\n"
-        "   [common_name_latin_name_id] INTEGER,\n"
-        "   FOREIGN KEY([common_name_latin_name_id]) REFERENCES [common_name_latin_name]([id])\n"
+        "   [common_name_latin_name_id] INTEGER REFERENCES [common_name_latin_name]([id])\n"
         ")"
     )
     assert (
@@ -158,16 +153,14 @@ def test_reuse_lookup_table(fresh_db):
     assert fresh_db["sightings"].schema == (
         'CREATE TABLE "sightings" (\n'
         "   [id] INTEGER PRIMARY KEY,\n"
-        "   [species_id] INTEGER,\n"
-        "   FOREIGN KEY([species_id]) REFERENCES [species]([id])\n"
+        "   [species_id] INTEGER REFERENCES [species]([id])\n"
         ")"
     )
     assert fresh_db["individuals"].schema == (
         'CREATE TABLE "individuals" (\n'
         "   [id] INTEGER PRIMARY KEY,\n"
         "   [name] TEXT,\n"
-        "   [species_id] INTEGER,\n"
-        "   FOREIGN KEY([species_id]) REFERENCES [species]([id])\n"
+        "   [species_id] INTEGER REFERENCES [species]([id])\n"
         ")"
     )
     assert list(fresh_db["species"].rows) == [
