@@ -1,5 +1,5 @@
 from sqlite_utils.utils import rows_from_file, Format, RowError
-from io import BytesIO
+from io import BytesIO, StringIO
 import pytest
 
 
@@ -44,3 +44,11 @@ def test_rows_from_file_extra_fields_strategies(ignore_extras, extras_key, expec
             # We did not expect an error
             raise
     assert list_rows == expected
+
+
+def test_rows_from_file_error_on_string_io():
+    with pytest.raises(TypeError) as ex:
+        rows_from_file(StringIO("id,name\r\n1,Cleo"))
+    assert ex.value.args == (
+        "rows_from_file() requires a file-like object that supports peek(), such as io.BytesIO",
+    )
